Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(794)

Unified Diff: pkg/analysis_server/lib/src/analysis_server.dart

Issue 756403004: Shutdown instrumentation (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analysis_server/lib/src/analysis_server.dart
diff --git a/pkg/analysis_server/lib/src/analysis_server.dart b/pkg/analysis_server/lib/src/analysis_server.dart
index 4e79eba44d6d2b70ec47a9a7c477481b4917870e..dac925c66f5154e1b565eb0dd20f626fc30dd596 100644
--- a/pkg/analysis_server/lib/src/analysis_server.dart
+++ b/pkg/analysis_server/lib/src/analysis_server.dart
@@ -820,8 +820,12 @@ class AnalysisServer {
index.clear();
index.stop();
}
- // Defer closing the channel so that the shutdown response can be sent.
- new Future(channel.close);
+ // Defer closing the channel and shutting down the instrumentation server so
+ // that the shutdown response can be sent and logged.
+ new Future(() {
+ channel.close();
+ instrumentationServer.shutdown();
+ });
}
/**
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698